PyXMake Developer Guide: PyXMake.Build.Make.SSH Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.SSH Class Reference

Base class for all build events requiring a SSH connection. More...

Inheritance diagram for PyXMake.Build.Make.SSH:

## Public Member Functions
def | __init__ (self, args, kwargs)
def | OutputPath (self, libpath, modulepath=None)
def | Settings (self, user, key, host='129.247.54.37', port=22)
def | Environment (self, path="", bash="", args="")
def | Postprocessing (self, cmdstring="")
def | Build (self, cmdstring, run="ifort", path="", lib="", linkedIn="")
def | create (self, kwargs)
Public Member Functions inherited from PyXMake.Build.Make.Make
def | __init__ (self, BuildID, Srcs, scratch=os.getcwd(), msvsc='vs2015', stype='Fortran', verbose=0, args, kwargs)
def | __getstate__ (self)
def | __setstate__ (self, _dict)
def | AddIncludePath (self, includes)
def | AddDependencyPath (self, dependencies)
def | UseLibraries (self, libs)
def | SourcePath (self, path)
def | OutputPath (self, path, files="")
def | Environment (self, path, script="ifortvars.bat")
def | Preprocessing
def | Build (self, cmdstring)
def | Postprocessing (self, cmdstring='')
def | create (self)

## Public Attributes
| intermediate_wrapper
| Wrapper interface file for 3rd party FORTRAN code. More...
| wrapper_source
| wrapper_module
| MakeObjectKind
| String identifier of current instance. More...
| libname
| Name of library, assembled using BuildID. More...
| buildname
| Temporary build name. More...
| export
| Environment variables to be set prior to the execution of the build command. More...
| incremental
| Define if the input should be compiled exactly as provided. More...
| linkedIn
| List of libraries which should be statically linked in. More...
| temps
| Blank version of tuple to store temporary file names scheduled for removal. More...
| environment
| Load an additional library prior to execution of all commands. More...
| libdirs
| Blank version of list containing library directories. More...
| outmodule
| Output path for module or header files. More...
| outlibs
| Output path for library files. More...
| workspace
| Remote workspace. More...
| ssh_client
| Instance of SSHClient to establish a SSH connection. More...
| postcmd
| Command executed during post-build event. More...
| libs
| path2exe
| (Intel Fortran) Compiler Path
| exe
| makecmd
| Remote (Intel) Compiler command. More...
| linkcmd
| Remote Linker command. More...
| command
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid
| Base string of build object. More...
| srcs
| Source file or folders.
| stype
| Source file type.
| verbose
| Level of verbosity of the current build object. More...
| scrtdir
| Current scratch directory.
| srcdir
| Default search directory for source files. More...
| outdir
| Default search directory for output. More...
| intelpath
| Path to Intel Fortran Compiler (read from Paths.log). More...
| temps
| Tuple of data to be removed after job completion. More...
| incdirs
| List of include directories. More...
| libdirs
| List of library directories. More...
| libs
| List of actual libraries (by name) used during linking. More...
| copyfiles
| List of files to be copied to the output directory after finish. More...
| setarch
| Define the architecture for the build directly by using the keyword argument "arch". More...
| architecture
| Processor architecture.
| iniCompiler
| Executable batch script (including absolute system path) to set up the Intel Fortran Compiler. More...
| msvsc
| Default version of Microsoft visual studio used by the Intel Fortran Compiler. More...
| postcmd
| Post build command. More...
| buildname
| precmd
| Command executed during pre-build event. More...
| compargs
| Command line arguments passed in by the user. More...
| makecmd
| Command executed during build event. More...

## Detailed Description

Base class for all build events requiring a SSH connection.

    Inherited class for all builds using SSH connection.

Inherited from Make.

Definition at line 1838 of file Make.py.

## Constructor & Destructor Documentation

## ◆ __init__()

def PyXMake.Build.Make.SSH.__init__ | ( |  | self,
|  |  | args,
|  |  | kwargs
| ) |  |

    Initialization of SSH class object.

Definition at line 1842 of file Make.py.

## Member Function Documentation

## ◆ Build()

def PyXMake.Build.Make.SSH.Build | ( |  | self,
|  |  | cmdstring,
|  |  | run = `"ifort"`,
|  |  | path = `""`,
|  |  | lib = `""`,
|  |  | linkedIn = `""`
| ) |  |

    Assemble command strings for the main build event.

Definition at line 1938 of file Make.py.

## ◆ create()

def PyXMake.Build.Make.SSH.create | ( |  | self,
|  |  | kwargs
| ) |  |

    Define settings to establish SSH connection.

Definition at line 1991 of file Make.py.

## ◆ Environment()

def PyXMake.Build.Make.SSH.Environment | ( |  | self,
|  |  | path = `""`,
|  |  | bash = `""`,
|  |  | args = `""`
| ) |  |

    Load an additional environment file prior to execution of all commands.

Definition at line 1922 of file Make.py.

## ◆ OutputPath()

def PyXMake.Build.Make.SSH.OutputPath | ( |  | self,
|  |  | libpath,
|  |  | modulepath = `None`
| ) |  |

    Define output directories for modules and libraries. Output written to the workspace is DELETED.

Definition at line 1895 of file Make.py.

## ◆ Postprocessing()

def PyXMake.Build.Make.SSH.Postprocessing | ( |  | self,
|  |  | cmdstring = `""`
| ) |  |

    Assemble command string for the post-build event.

Definition at line 1930 of file Make.py.

## ◆ Settings()

def PyXMake.Build.Make.SSH.Settings | ( |  | self,
|  |  | user,
|  |  | key,
|  |  | host = `'129.247.54.37'`,
|  |  | port = `22`
| ) |  |

    Define settings to establish a SSH connection.

Definition at line 1908 of file Make.py.

## Member Data Documentation

## ◆ buildname

PyXMake.Build.Make.SSH.buildname

Temporary build name.

Definition at line 1864 of file Make.py.

## ◆ environment

PyXMake.Build.Make.SSH.environment

Load an additional library prior to execution of all commands.

Defaults to an empty string.

Definition at line 1887 of file Make.py.

## ◆ export

PyXMake.Build.Make.SSH.export

Environment variables to be set prior to the execution of the build command.

Intel Fortran 12+

Definition at line 1866 of file Make.py.

## ◆ incremental

PyXMake.Build.Make.SSH.incremental

Define if the input should be compiled exactly as provided.

Defaults to False, meaning that merging & pre-processing utilities will be carried out.

Definition at line 1876 of file Make.py.

## ◆ intermediate_wrapper

PyXMake.Build.Make.SSH.intermediate_wrapper

Wrapper interface file for 3rd party FORTRAN code.

Automatically creates a module of the underlying source material.

Definition at line 1853 of file Make.py.

## ◆ libdirs

PyXMake.Build.Make.SSH.libdirs

Blank version of list containing library directories.

MKL library has been removed since location on the SSH remote computer is not known a priori.

Definition at line 1892 of file Make.py.

## ◆ libname

PyXMake.Build.Make.SSH.libname

Name of library, assembled using BuildID.

Definition at line 1862 of file Make.py.

## ◆ linkcmd

PyXMake.Build.Make.SSH.linkcmd

Remote Linker command.

Simply execute UNIX archiver.

Remote Intel Linker command.

Do no use any archiver

Definition at line 1982 of file Make.py.

## ◆ linkedIn

PyXMake.Build.Make.SSH.linkedIn

List of libraries which should be statically linked in.

Definition at line 1880 of file Make.py.

## ◆ makecmd

PyXMake.Build.Make.SSH.makecmd

Remote (Intel) Compiler command.

Definition at line 1977 of file Make.py.

## ◆ MakeObjectKind

PyXMake.Build.Make.SSH.MakeObjectKind

String identifier of current instance.

Definition at line 1858 of file Make.py.

## ◆ outlibs

PyXMake.Build.Make.SSH.outlibs

Output path for library files.

Definition at line 1905 of file Make.py.

## ◆ outmodule

PyXMake.Build.Make.SSH.outmodule

Output path for module or header files.

Definition at line 1903 of file Make.py.

## ◆ postcmd

PyXMake.Build.Make.SSH.postcmd

Command executed during post-build event.

Definition at line 1935 of file Make.py.

## ◆ ssh_client

PyXMake.Build.Make.SSH.ssh_client

Instance of SSHClient to establish a SSH connection.

Definition at line 1917 of file Make.py.

## ◆ temps

PyXMake.Build.Make.SSH.temps

Blank version of tuple to store temporary file names scheduled for removal.

Definition at line 1884 of file Make.py.

## ◆ workspace

PyXMake.Build.Make.SSH.workspace

Remote workspace.

This is the scratch directory for the build event. Defaults to /home/user/.

Definition at line 1915 of file Make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Build/Make.py